@@ -1,5 +1,5 @@
 """Function annotations to implement `Handlers <https://docs.symops.com/docs/handlers>`_."""
 
-__all__ = ["hook", "reducer", "action"]
+__all__ = ["hook", "reducer"]
 
-from ._handlers import action, hook, reducer
+from ._handlers import hook, reducer
