@@ -1,4 +1,4 @@
-from sym.sdk import action, hook, reducer
+from sym.sdk import hook, reducer
 
 
 @hook
@@ -11,13 +11,7 @@ def simple_reducer():
     return "simple_reducer"
 
 
-@action
-def simple_action():
-    return "simple_action"
-
-
 class TestReducer:
     def test_all(self):
         assert simple_hook() == "simple_hook"
         assert simple_reducer() == "simple_reducer"
-        assert simple_action() == "simple_action"
